@@ -714,7 +714,7 @@ Net::EPP::Server - A simple EPP server implementation.
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -807,7 +807,7 @@ Provisioning Protocol (EPP)|https://www.rfc-editor.org/info/std69> servers.
 
 It implements the TLS/TCP transport described in L<RFC 5734|https://www.rfc-editor.org/info/rfc5734>,
 and the L<EPP Server State Machine|https://www.rfc-editor.org/rfc/rfc5730.html#:~:text=Figure%201:%20EPP%20Server%20State%20Machine>
-described in L<Section 2 of RFC 5730|https://www.rfc-editor.org/rfc/rfc5730.html>.
+described in L<Section 2 of RFC 5730|https://www.rfc-editor.org/rfc/rfc5730.html#section-2>.
 
 =head1 SERVER CONFIGURATION
 
@@ -1128,7 +1128,7 @@ Gavin Brown <gavin.brown@icann.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2024 by Internet Corporation for Assigned Names and Number (ICANN).
+This software is copyright (c) 2025 by Internet Corporation for Assigned Names and Number (ICANN).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
